from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name='twyclip',
    version='1.0.2',
    description='TwyClip is a Python library for get Twitch clip download link.',
    packages=find_packages(),
    long_description=long_description,
    long_description_content_type='text/markdown',
    # url="",
    author='John Doe',
    license='The Unlicense (Unlicense)',
    install_requires=['requests'],
    keywords=['twitch'],
    python_requires='>=3.8'
)
# python setup.py sdist bdist_wheel
# twine upload dist/*


import requests

def clipData(clip_url):
	clip_response = requests.get(f"https://twiclips.com/twitch-download/clip?clip_url={clip_url}")
	clip_json = clip_response.json()
	return {
		'title': clip_json['data']['title'],
		'author': clip_json['data']['info']['author'],
		'category': clip_json['data']['info']['category'],
		'clip_author': clip_json['data']['info']['clip_author'],
		'date': clip_json['data']['info']['date'],
		'views': clip_json['data']['info']['views'],
		'download_link': clip_json['data']['info']['play_url']
	}